# Changelog

## [v0.3.0](https://github.com/astrochun/github-stats-pages/tree/v0.3.0) (2021-03-23)

**Implemented enhancements:**
 - Module and script to generate plots; add CHANGELOG.md [#17](https://github.com/astrochun/github-stats-pages/pull/17)

**Closed issues:**
 - Module and script to generate plots [#16](http://github.com/astrochun/github-stats-pages/issues/16)
 - Add CHANGELOG.md [#18](http://github.com/astrochun/github-stats-pages/issues/18)


**Merged pull requests:**

## [v0.2.0](https://github.com/astrochun/github-stats-pages/tree/v0.2.0) (2021-02-27)

**Implemented enhancements:**
 - Include github-traffic-stats and use it [#13](http://github.com/astrochun/github-stats-pages/pull/13)

**Closed issues:**
 - Include github-traffic-stats and use it [#2](http://github.com/astrochun/github-stats-pages/issues/2)

**Merged pull requests:**
 - chore: add sponsorship [#15](https://github.com/astrochun/github-stats-pages/pull/15)


## [v0.1.5](https://github.com/astrochun/github-stats-pages/tree/v0.1.5) (2021-02-01)

**Implemented enhancements:**
 - Update setup.py to include additional classifier, README description [#12](http://github.com/astrochun/github-stats-pages/pull/12)

**Closed issues:**
 - Update setup.py to include additional classifier, README description [#11](http://github.com/astrochun/github-stats-pages/issues/11)


## [v0.1.4](https://github.com/astrochun/github-stats-pages/tree/v0.1.4) (2021-02-01)

**Implemented enhancements:**
 - Publish to PyPI using GitHub Actions [#10](http://github.com/astrochun/github-stats-pages/pull/10)

**Closed issues:**
 - Publish to PyPI using GitHub Actions [#9](http://github.com/astrochun/github-stats-pages/issues/9)


## [v0.1.3](https://github.com/astrochun/github-stats-pages/tree/v0.1.3) (2021-01-30)

**Bug fixes:**
 - Fix branch settings for GitHub badge [#7](http://github.com/astrochun/github-stats-pages/issues/7)

**Merged pull requests:**
 - Fix branch settings for GitHub badge [#8](http://github.com/astrochun/github-stats-pages/pull/8)


## [v0.1.2](https://github.com/astrochun/github-stats-pages/tree/v0.1.2) (2021-01-30)

**Fixed bugs:**
 - Add missing scripts in setup.py
 - Add python-package GitHub Actions for build and unit tests
 - Add GitHub badges to README.md
 - Update .gitignore to exclude .idea settings
 - Bump version: v0.1.0 -> v0.1.2


## [v0.1.1](https://github.com/astrochun/github-stats-pages/tree/v0.1.1) (2021-01-30)

**Fixed bugs:**
 - Correct path for github workflow [#4](http://github.com/astrochun/github-stats-pages/issues/4)

**Merged pull requests:**
 - Correct path for github workflow [#5](http://github.com/astrochun/github-stats-pages/pull/5)


## [v0.1.0](https://github.com/astrochun/github-stats-pages/tree/v0.1.0) (2021-01-30)

**Implemented enhancements:**
 - Get public repository lists [#3](http://github.com/astrochun/github-stats-pages/pull/3)

**Closed issues:**
 - GET list of public repositories for a user [#1](http://github.com/astrochun/github-stats-pages/issues/1)


<!-- TEMPLATE
## [vXX.YY.ZZ](https://github.com/astrochun/github-stats-pages/tree/vXX.YY.ZZ) (YYYY-MM-DD)

**Implemented enhancements:**
 - `______` [#XX](http://github.com/astrochun/github-stats-pages/pull/XX)

**Fixed bugs:**
 - `______` [#XX](http://github.com/astrochun/github-stats-pages/issues/XX)

**Closed issues:**
 - `______` [#XX](http://github.com/astrochun/github-stats-pages/issues/XX)

**Merged pull requests:**
 - `______` [#XX](http://github.com/astrochun/github-stats-pages/pull/XX)

-->